@@ -89,17 +89,6 @@ def load_thai_admin_areas(dir_path):
         mtx_lv3_concat_en = pickle.load(f)
 
 
-def char_level(txt):
-    for word in txt.split():
-        for cha in word:
-            yield cha
-
-
-def token_level(txt):
-    for word in txt.split(" "):
-        yield word.strip(",")
-
-
 def extract_postal(text, default_value=None):
     match = re.search(POSTAL_CODE_EXP, text[-20:])
     if match is not None:
@@ -656,7 +645,7 @@ def match_thai_vendor_addresses(customer_address, vendor_addresses, text_dist_th
 
         if np.any(pinpoint_sim > text_dist_thresh):
             for ind in np.argwhere(pinpoint_sim > text_dist_thresh).flatten():
-                result[ind] = pinpoint_sim[ind]
+                result[ind] = float(pinpoint_sim[ind])
         else:
             for ind in np.argwhere(admin_area_matched).flatten():
                 result[ind] = 0.95
